@@ -328,11 +328,11 @@ static int yaz_solr_decode_scan_result(ODR o, xmlNodePtr ptr,
 int yaz_solr_decode_response(ODR o, Z_HTTP_Response *hres, Z_SRW_PDU **pdup)
 {
     int ret = -1;
+    Z_SRW_PDU *pdu = 0;
 #if YAZ_HAVE_XML2
     const char *content_buf = hres->content_buf;
     int content_len = hres->content_len;
     xmlDocPtr doc = xmlParseMemory(content_buf, content_len);
-    Z_SRW_PDU *pdu = 0;
 
     if (doc)
     {
@@ -342,8 +342,7 @@ int yaz_solr_decode_response(ODR o, Z_HTTP_Response *hres, Z_SRW_PDU **pdup)
         xmlNodePtr root = xmlDocGetRootElement(doc);
         if (root && !strcmp((const char *) root->name, "response"))
         {
-            ret = 0;
-            for (ptr = root->children; ptr && !ret; ptr = ptr->next)
+            for (ptr = root->children; ptr; ptr = ptr->next)
             {
                 if (ptr->type == XML_ELEMENT_NODE &&
                     !strcmp((const char *) ptr->name, "result"))
@@ -377,9 +376,8 @@ int yaz_solr_decode_response(ODR o, Z_HTTP_Response *hres, Z_SRW_PDU **pdup)
         }
         xmlFreeDoc(doc);
     }
-    if (ret == 0)
-        *pdup = pdu;
 #endif
+    *pdup = pdu;
     return ret;
 }
 
@@ -480,6 +478,12 @@ int yaz_solr_encode_request(Z_HTTP_Request *hreq, Z_SRW_PDU *srw_pdu,
     int no_parms = 20; /* safe upper limit of args without extra_args */
     Z_SRW_extra_arg *ea;
 
+    if (srw_pdu->which == Z_SRW_searchRetrieve_request)
+    {   /* to make room for facets in yaz_solr_encode_facet_list later */
+        Z_SRW_searchRetrieveRequest *request = srw_pdu->u.request;
+        if (request->facetList)
+            no_parms += request->facetList->num;
+    }
     for (ea = srw_pdu->extra_args; ea; ea = ea->next)
         no_parms++;
     name = (char **) odr_malloc(encode, sizeof(*name) * no_parms);
